import joptsimple.OptionException;
import joptsimple.OptionParser;
import joptsimple.OptionSet;
import joptsimple.OptionSpec;

import java.io.IOException;
import java.util.ArrayList;


/**
 * Demo illustrating how to use the JOpt Simple library to process command line
 * arguments. This application will print each provided word some number of
 * times, optionally converting all words to upper-case.
 * 
 * @author Nathan Sprague
 * @version 10/2016
 */
public class CliDemo {

  /**
   * Process the command line arguments and print the words to the terminal.
   * Print a help message if there is a problem parsing the command line
   * arguments.
   */
  public static void main(String[] args) throws IOException {

    // Set up the option parser with the desired arguments.
    OptionParser parser = new OptionParser();

    OptionSpec<Integer> numSpec =
        parser.accepts("n", "number of times to print each provided word (must be non-negative)")
            .withRequiredArg()
            .ofType(Integer.class)
            .describedAs("NUMBER")
            .required();

    OptionSpec<String> wordSpec =
        parser.accepts("w", "the word or words to print")
            .withOptionalArg()
            .describedAs("WORD1,WORD2,...")
            .ofType(String.class)
            .withValuesSeparatedBy(",");

    parser.accepts("u", "convert to upper-case");
    

    try {

      // Parse the command line arguments. This will raise an exception if the
      // arguments are not formatted correctly on the command line.
      OptionSet options = parser.parse(args);

      // Extract the arguments.
      int numTimes = options.valueOf(numSpec);

      if (numTimes < 0) {
        System.out.println("Option n must be non-negative\n");
        printHelpAndExit(parser);
      }

      ArrayList<String> words = new ArrayList<>(options.valuesOf(wordSpec));
      if (words.isEmpty()) {
        words.add("Hello");
      }

      if (options.has("u")) {
        for (int i = 0; i < words.size(); i++) {
          words.set(i, words.get(i).toUpperCase());
        }
      }

      // Now we are ready to do the printing.
      for (String word : words) {
        for (int i = 0; i < numTimes; i++) {
          System.out.println(word);
        }
      }

    } catch (OptionException exception) {
      System.out.println(exception.getMessage() + "\n");
      printHelpAndExit(parser);
    }
  }

  private static void printHelpAndExit(OptionParser parser) throws IOException {
    parser.printHelpOn(System.out);
    System.exit(0);
  }

}
